chiark / gitweb /
Infrastructure: Export pkgconfig file.
[mLib] / conn.h
diff --git a/conn.h b/conn.h
index 7362b6557a2fb50d14ff814fdf88382640cb2f6d..bee4fce129f4054d70ddc769757d5f49f6374eb5 100644 (file)
--- a/conn.h
+++ b/conn.h
@@ -1,13 +1,13 @@
 /* -*-c-*-
  *
- * $Id: conn.h,v 1.1 1999/05/14 21:01:14 mdw Exp $
+ * $Id: conn.h,v 1.8 2004/04/08 01:36:11 mdw Exp $
  *
  * Nonblocking connect handling
  *
- * (c) 1999 Mark Wooding
+ * (c) 1999 Straylight/Edgeware
  */
 
-/*----- Licensing notice --------------------------------------------------* 
+/*----- Licensing notice --------------------------------------------------*
  *
  * This file is part of the mLib utilities library.
  *
  * it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
- * 
+ *
  * mLib is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Library General Public
  * License along with mLib; if not, write to the Free
  * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
  * MA 02111-1307, USA.
  */
 
-/*----- Revision history --------------------------------------------------* 
- *
- * $Log: conn.h,v $
- * Revision 1.1  1999/05/14 21:01:14  mdw
- * Integrated `select' handling bits from the background resolver project.
- *
- */
-
-#ifndef CONN_H
-#define CONN_H
+#ifndef MLIB_CONN_H
+#define MLIB_CONN_H
 
 #ifdef __cplusplus
   extern "C" {
 
 /*----- Header files ------------------------------------------------------*/
 
-#ifndef SEL_H
+#include <sys/types.h>
+#include <sys/socket.h>
+
+#ifndef MLIB_SEL_H
 #  include "sel.h"
 #endif
 
@@ -60,35 +55,49 @@ typedef struct conn {
 
 /*----- Functions provided ------------------------------------------------*/
 
-/* --- @conn_init@ --- *
+/* --- @conn_fd@ --- *
  *
  * Arguments:  @conn *c@ = pointer to connection block
  *             @sel_state *s@ = pointer to select state to attach to
- *             @unsigned long saddr@ = source IP address
- *             @unsigned short sport@ = source port
- *             @unsigned long daddr@ = destination IP address
- *             @unsigned short dport@ = destination port
+ *             @int fd@ = file descriptor of socket
  *             @void (*func)(int fd, void *p) = handler function
  *             @void *p@ = argument for the handler function
  *
  * Returns:    ---
  *
- * Use:                Sets up a nonblocking connect job.  The source address and
- *             port can be zero if you don't care.  When the connection
- *             completes, the handler function is called with the connected
- *             socket as an argument.  If the connect fails rather than
- *             completes, the handler is informed of this by being passed a
- *             negative file descriptor.  In either case, the select job is
- *             then removed.
+ * Use:                Sets up a nonblocking connect job.  The socket should have a
+ *             connect pending for it already.
+ */
+
+void conn_fd(conn */*c*/, sel_state */*s*/, int /*fd*/,
+            void (*/*func*/)(int /*fd*/, void */*p*/),
+            void */*p*/);
+
+/* --- @conn_init@ --- *
+ *
+ * Arguments:  @conn *c@ = pointer to connection block
+ *             @sel_state *s@ = pointer to select state to attach to
+ *             @int fd@ = file descriptor of socket to connect
+ *             @struct sockaddr *dst@ = destination address
+ *             @int dsz@ = size of destination address
+ *             @void (*func)(int fd, void *p) = handler function
+ *             @void *p@ = argument for the handler function
+ *
+ * Returns:    Zero on success, nonzero on failure.
+ *
+ * Use:                Sets up a nonblocking connect job.  The socket should already
+ *             be bound if you care about that sort of thing.  When the
+ *             connection completes, the handler function is called with the
+ *             connected socket as an argument.  If the connect fails rather
+ *             than completes, the socket is closed, and the handler is
+ *             informed of this by being passed a negative file descriptor.
+ *             In either case, the select job is then removed.
  */
 
-extern void conn_init(conn */*c*/, sel_state */*s*/,
-                     unsigned long /*saddr*/,
-                     unsigned short /*sport*/,
-                     unsigned long /*daddr*/,
-                     unsigned long /*dport*/,
-                     void (*/*func*/)(int /*fd*/, void */*p*/),
-                     void */*p*/);
+extern int conn_init(conn */*c*/, sel_state */*s*/, int /*fd*/,
+                    struct sockaddr */*dst*/, int /*dsz*/,
+                    void (*/*func*/)(int /*fd*/, void */*p*/),
+                    void */*p*/);
 
 /* --- @conn_kill@ --- *
  *